# Installation <br>
`pip install x0m-quickserver`

#License <br>
#### MIT

#Info <br>
quickserver is a simple appliucation for starting quick server from your terminal
# Starting a Server <br>

````bash
quickserver <html file location for your server>
````
# Ownership <br>
This package is made as an extension of x0mb3 Foundation !
